<?php
/**
 * Law Firm Lite Theme Customizer
 *
 * @package Law Firm Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function law_firm_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'law_firm_lite_custom_controls' );

function law_firm_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'law_firm_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'law-firm-lite' ),
	) );

	// Layout
	$wp_customize->add_section( 'law_firm_lite_left_right', array(
    	'title'      => __( 'General Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_width_option',array(
        'default' => __('Full Width','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Law_Firm_Lite_Image_Radio_Control($wp_customize, 'law_firm_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','law-firm-lite'),
        'description' => __('Here you can change the width layout of Website.','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('law_firm_lite_theme_options',array(
        'default' => __('Right Sidebar','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'	        
	) );
	$wp_customize->add_control('law_firm_lite_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','law-firm-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','law-firm-lite'),
            'Right Sidebar' => __('Right Sidebar','law-firm-lite'),
            'One Column' => __('One Column','law-firm-lite'),
            'Three Columns' => __('Three Columns','law-firm-lite'),
            'Four Columns' => __('Four Columns','law-firm-lite'),
            'Grid Layout' => __('Grid Layout','law-firm-lite')
        ),
	));

	$wp_customize->add_setting('law_firm_lite_page_layout',array(
        'default' => __('One Column','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control('law_firm_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','law-firm-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','law-firm-lite'),
            'Right Sidebar' => __('Right Sidebar','law-firm-lite'),
            'One Column' => __('One Column','law-firm-lite')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'law_firm_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','law-firm-lite' ),
		'section' => 'law_firm_lite_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'law_firm_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','law-firm-lite' ),
		'section' => 'law_firm_lite_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'law_firm_lite_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','law-firm-lite' ),
        'section' => 'law_firm_lite_left_right'
    )));

	$wp_customize->add_setting('law_firm_lite_loader_icon',array(
        'default' => __('Two Way','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control('law_firm_lite_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','law-firm-lite'),
            'Dots' => __('Dots','law-firm-lite'),
            'Rotate' => __('Rotate','law-firm-lite')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'law_firm_lite_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting( 'law_firm_lite_topbar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_topbar_hide_show',array(
		'label' => esc_html__( 'Show / Hide Topbar','law-firm-lite' ),
		'section' => 'law_firm_lite_topbar'
    )));

    //Sticky Header
	$wp_customize->add_setting( 'law_firm_lite_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','law-firm-lite' ),
        'section' => 'law_firm_lite_topbar'
    )));

	$wp_customize->add_setting( 'law_firm_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','law-firm-lite' ),
      	'section' => 'law_firm_lite_topbar'
    )));

	$wp_customize->add_setting('law_firm_lite_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_location',array(
		'label'	=> __('Add Location','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( '123 Dunmmy street lorem ipsum, USA', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_open_time',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_open_time',array(
		'label'	=> __('Add Opening Time','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Mon to Sat 9:00am - 8:00pm', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_top_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_top_btn_text',array(
		'label'	=> __('Add Button Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'FREE EVALUATION', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_top_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('law_firm_lite_top_btn_url',array(
		'label'	=> __('Add Button URL','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'https://example.com/', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'url'
	));
    
	//Slider
	$wp_customize->add_section( 'law_firm_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting( 'law_firm_lite_slider_arrows',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','law-firm-lite' ),
      	'section' => 'law_firm_lite_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'law_firm_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'law_firm_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'law_firm_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'law-firm-lite' ),
			'description' => __('Slider image size (1500 x 800)','law-firm-lite'),
			'section'  => 'law_firm_lite_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('law_firm_lite_slider_content_option',array(
        'default' => __('Left','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Law_Firm_Lite_Image_Radio_Control($wp_customize, 'law_firm_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','law-firm-lite'),
        'section' => 'law_firm_lite_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'law_firm_lite_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'law_firm_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','law-firm-lite' ),
		'section'     => 'law_firm_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'law_firm_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('law_firm_lite_slider_opacity_color',array(
      'default'              => 0.3,
      'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'law_firm_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','law-firm-lite' ),
	'section'     => 'law_firm_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'law_firm_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','law-firm-lite'),
      '0.1' =>  esc_attr('0.1','law-firm-lite'),
      '0.2' =>  esc_attr('0.2','law-firm-lite'),
      '0.3' =>  esc_attr('0.3','law-firm-lite'),
      '0.4' =>  esc_attr('0.4','law-firm-lite'),
      '0.5' =>  esc_attr('0.5','law-firm-lite'),
      '0.6' =>  esc_attr('0.6','law-firm-lite'),
      '0.7' =>  esc_attr('0.7','law-firm-lite'),
      '0.8' =>  esc_attr('0.8','law-firm-lite'),
      '0.9' =>  esc_attr('0.9','law-firm-lite')
	),
	));

	//Contact
	$wp_customize->add_section( 'law_firm_lite_contact', array(
    	'title'      => __( 'Contact Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_calling_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_calling_text',array(
		'label'	=> __('Add Calling Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Call us for free consultation', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_calling_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_calling_number',array(
		'label'	=> __('Add Calling Number','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 654 654', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_email_text',array(
		'label'	=> __('Add Email Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Drop us Mail', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_email_address',array(
		'label'	=> __('Add Email Address','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'example@123.com', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));
    
	//Our Practise Area section
	$wp_customize->add_section( 'law_firm_lite_services_section' , array(
    	'title'      => __( 'Our Practice Area', 'law-firm-lite' ),
		'priority'   => null,
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_section_title',array(
		'label'	=> __('Add Section Title','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Practise Areas', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_services_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_section_text',array(
		'label'	=> __('Add Section Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'HIGH LEVEL SERVICES', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_services_section',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('law_firm_lite_our_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'law_firm_lite_sanitize_choices',
	));
	$wp_customize->add_control('law_firm_lite_our_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Services','law-firm-lite'),
		'description' => __('Image Size (370 x 370)','law-firm-lite'),
		'section' => 'law_firm_lite_services_section',
	));

	//Practice excerpt
	$wp_customize->add_setting( 'law_firm_lite_practice_excerpt_number', array(
		'default'              => 10,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'law_firm_lite_practice_excerpt_number', array(
		'label'       => esc_html__( 'Practice Excerpt length','law-firm-lite' ),
		'section'     => 'law_firm_lite_services_section',
		'type'        => 'range',
		'settings'    => 'law_firm_lite_practice_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('law_firm_lite_blog_post',array(
		'title'	=> __('Blog Post Settings','law-firm-lite'),
		'panel' => 'law_firm_lite_panel_id',
	));	

	$wp_customize->add_setting( 'law_firm_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','law-firm-lite' ),
        'section' => 'law_firm_lite_blog_post'
    )));

    $wp_customize->add_setting( 'law_firm_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_toggle_author',array(
		'label' => esc_html__( 'Author','law-firm-lite' ),
		'section' => 'law_firm_lite_blog_post'
    )));

    $wp_customize->add_setting( 'law_firm_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_toggle_comments',array(
		'label' => esc_html__( 'Comments','law-firm-lite' ),
		'section' => 'law_firm_lite_blog_post'
    )));

    $wp_customize->add_setting( 'law_firm_lite_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'law_firm_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','law-firm-lite' ),
		'section'     => 'law_firm_lite_blog_post',
		'type'        => 'range',
		'settings'    => 'law_firm_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('law_firm_lite_blog_layout_option',array(
        'default' => __('Default','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
    ));
    $wp_customize->add_control(new Law_Firm_Lite_Image_Radio_Control($wp_customize, 'law_firm_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','law-firm-lite'),
        'section' => 'law_firm_lite_blog_post',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

	//Content Craetion
	$wp_customize->add_section( 'law_firm_lite_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'law-firm-lite' ),
		'priority' => null,
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new Law_Firm_Lite_Content_Creation( $wp_customize, 'law_firm_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','law-firm-lite' ),
		),
		'section' => 'law_firm_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'law-firm-lite' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('law_firm_lite_footer',array(
		'title'	=> __('Footer Settings','law-firm-lite'),
		'panel' => 'law_firm_lite_panel_id',
	));	
	
	$wp_customize->add_setting('law_firm_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('law_firm_lite_footer_text',array(
		'label'	=> __('Copyright Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'law_firm_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'law_firm_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','law-firm-lite' ),
      	'section' => 'law_firm_lite_footer'
    )));

	$wp_customize->add_setting('law_firm_lite_scroll_top_alignment',array(
        'default' => __('Right','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Law_Firm_Lite_Image_Radio_Control($wp_customize, 'law_firm_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','law-firm-lite'),
        'section' => 'law_firm_lite_footer',
        'settings' => 'law_firm_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'law_firm_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Law_Firm_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Law_Firm_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Law_Firm_Lite_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 1,
			'title'    => esc_html__( 'LAW FIRM PRO', 'law-firm-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'law-firm-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/law-firm-wordpress-theme/'),
		)));

		$manager->add_section(new Law_Firm_Lite_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'law-firm-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'law-firm-lite' ),
			'pro_url'  => admin_url('themes.php?page=law_firm_lite_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'law-firm-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'law-firm-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Law_Firm_Lite_Customize::get_instance();